# -*- coding: utf-8 -*-
from dataclasses import dataclass


@dataclass
class SecurityParam(object):
    """股票信息的实体类，用于构建行情查询接口的参数"""
    data_type: int  # 股票类型 参考常量类：DataType
    code: str  # 股票代码


class DataType(object):
    """股票类型"""
    HK_STOCK = 10000  # 港股股票
    HK_INDEX = 10001  # 港股指数
    HK_ETF = 10002  # 港股ETF
    HK_WARRANT = 10003  # 港股窝轮
    HK_CBBC = 10004  # 港股牛熊证
    HK_BOND = 10005  # 港股债券
    HK_INDUSTRY = 10006  # 港股行业板块
    HK_CONCEPT = 10007  # 港股概念板块
    HK_FUTURES = 10009  # 衍生品期货
    HK_INDEX_FUTURES = 10010  # 香港指数期货
    HK_STOCK_FUTURES = 10011  # 港股股票期货
    HK_DIVIDEND_POINT_INDEX_FUTURES = 10012  # 港股恒指股息期货
    HK_RMB_CURRENCY_FUTURES = 10013  # 港股人民币货币期货
    HK_CESC_INDEX_FUTURES = 10014  # 港股中华交易服务期货
    HK_VOLATILITY_INDEX_FUTURES = 10015  # 恒指波幅指数期货
    HK_INLINE = 10016  # 界内证
    US_STOCK = 20000  # 美股股票
    US_INDEX = 20001  # 美股指数
    US_ETF = 20002  # 美股ETF
    US_OPTION = 20003  # 美股期权
    US_INDUSTRY = 20006  # 美股行业板块
    US_CONCEPT = 20007  # 美股概念板块
    US_OTC = 20009  # 美股OTC
    ASHARE_STOCK = 30000  # A股股票
    ASHARE_INDEX = 30001  # A股指数
    ASHARE_ETF = 30002  # A股ETF
    ASHARE_INDUSTRY = 30006  # A股行业
    ASHARE_CONCEPT = 30007  # A股概念
    ASHARE_KSH = 30008  # A股科创板


class MktTmType(object):
    """
    交易时段
    美股：盘前：-1 盘中：1 盘后：-2
    """
    PRE_MARKET = -1  # 盘前：-1
    MID_SESSION = 1  # 盘中：1
    AFTER_HOURS = -2  # 盘后：-2


class DepthBookType(object):
    """
    2 3 totalview arcabook
    """
    TOTAL_VIEW = 2  # totalview
    ARCA_BOOK = 3  # arcabook


class CycType(object):
    """K线类型"""
    DAY = 2  # 日线
    WEEK = 3  # 周线
    MONTH = 4  # 月线
    MINUTE1 = 5  # 1分钟
    MINUTE5 = 6  # 5分钟
    MINUTE15 = 7  # 15分钟
    MINUTE30 = 8  # 30分钟
    MINUTE60 = 9  # 60分钟
    MINUTE120 = 10  # 120分钟
    QUARTER = 11  # 季度线
    YEAR = 12  # 年度线
    DAY5 = 13  # 五日
    MINUTE3 = 14  # 3分钟


class ExRightFlag(object):
    """复权类型"""
    BFQ = 0  # 不复权
    QFQ = 1  # 前复权
    HFQ = 2  # 后复权


class Direction(object):
    """查询方向"""
    QUERY_LEFT = 0  # 往左查询
    QUERY_RIGHT = 1  # 往右查询


class HQSubscribeTopicId(object):
    """订阅/取消订阅行情推送的TopicId"""
    BASIC_QOT = 11  # 基础行情推送
    TICKER = 14  # 逐笔推送
    TICKER_BF = 27  # 逐笔推送(盘前)
    TICKER_AF = 28  # 逐笔推送(盘后)
    BROKER = 16  # 买卖经纪推送
    ORDER_BOOK = 17  # 买卖档推送
    TOTALVIEW_BOOK = 26  # TOTALVIEW
    ARCA_BOOK = 25  # ARCA


class OptionPriceFlag(object):
    """
    期权 价内=1 价外=2
    """
    PRICE_IN = 1
    PRICE_OUT = 2


class OptionType(object):
    """
    期权类型 看涨=C 看跌P
    """
    CALL = "C"
    PUT = "P"
